@import '~@synerty/peek-theme/scss/_variables.web';

.peek-desktop-row {
    display: flex;
    height: 100%;
}

.peek-desktop-sidebar {
    // Set the flexbox sixe
    flex-grow: 0;
    flex-shrink: 0;
    flex-basis: $desktop_side_bar_width / 2;

    // Setup for Hide the scrollbar
    overflow: hidden;
    height: 100%;
}

.peek-desktop-sidebar-hidden {
    display:none;
}

.peek-desktop-sidebar-inner {

    overflow-y: auto;

    /* Make sure the inner div is not larger than the container
     * so that we have room to scroll.
     */
    height: 100%;

    /* Pick an arbitrary margin/padding that should be bigger
     * than the max width of all the scroll bars across
     * the devices you are targeting.
     * padding = -margin
     */
    margin-right: -100px;
    padding-right: 100px;
}

.peek-desktop-content {
    flex-grow: 1;
    overflow-y: auto;
}
