@import '~@synerty/peek-theme/scss/_variables.web';


.peek-dc-home-background {
    height: 100%;
    background-image: url('/assets/home-background.png');
    background-size: cover;
    background-color: $black;
}

.peek-dc-home-logo {
    margin: auto;
    object-fit: contain;
    width: 100%;
    max-height: 100%;
}
